// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KTEXTEDITOR_VERSION_H
#define KTEXTEDITOR_VERSION_H

#define KTEXTEDITOR_VERSION_STRING "5.98.0"
#define KTEXTEDITOR_VERSION_MAJOR 5
#define KTEXTEDITOR_VERSION_MINOR 98
#define KTEXTEDITOR_VERSION_PATCH 0
#define KTEXTEDITOR_VERSION ((5<<16)|(98<<8)|(0))

#endif
